@@ -37,6 +37,7 @@ from coordio import __version__ as coordio_version
 from coordio.defaults import INST_TO_WAVE, POSITIONER_HEIGHT, calibration
 from kaiju import __version__ as kaiju_version
 from sdssdb.peewee.sdss5db import opsdb, targetdb
+from sdsstools.time import get_sjd
 
 from jaeger import FPS
 from jaeger import __version__ as jaeger_version
@@ -52,7 +53,6 @@ from jaeger.kaiju import (
     load_robot_grid,
     warn,
 )
-from jaeger.utils import get_sjd
 from jaeger.utils.database import connect_database
 from jaeger.utils.helpers import run_in_executor
 
@@ -319,6 +319,7 @@ class BaseConfiguration:
         simple_decollision: bool = False,
         resolve_deadlocks: bool = True,
         n_deadlock_retries: int = 5,
+        path_generation_mode: str | None = None,
         force: bool = False,
     ) -> dict:
         """Returns a trajectory dictionary from the folded position.
@@ -338,6 +339,11 @@ class BaseConfiguration:
             minimise what robots move.
         resolve_deadlocks
             Whether to solve for deadlocks after decollision.
+        n_deadlock_retries
+            How many times to try solving deadlocks.
+        path_generation_mode
+            The path generation mode, either ``'greedy'`` or ``'mdp'``. If not
+            defined, uses the default path generation mode.
         force
             If `False`, fails if the robot grid is deadlocked. Always fails if there
             are collisions.
@@ -413,7 +419,11 @@ class BaseConfiguration:
         # Fix deadlocks (this sets the trajectories in the instance).
         self.log("Generating path pair.")
         n_retries = n_deadlock_retries if resolve_deadlocks else -1
-        unlocked = await self._resolve_deadlocks(n_retries=n_retries, force=force)
+        unlocked = await self._resolve_deadlocks(
+            n_retries=n_retries,
+            path_generation_mode=path_generation_mode,
+            force=force,
+        )
 
         self._update_coordinates(unlocked)
 
@@ -428,6 +438,7 @@ class BaseConfiguration:
     async def _resolve_deadlocks(
         self,
         n_retries: int = 5,
+        path_generation_mode: str | None = None,
         force: bool = False,
     ) -> list[int]:
         """Iteratively fix deadlocks."""
@@ -439,7 +450,10 @@ class BaseConfiguration:
         decollided: list[int] = []
 
         while True:
-            result = await get_path_pair_in_executor(self.robot_grid)
+            result = await get_path_pair_in_executor(
+                self.robot_grid,
+                path_generation_mode=path_generation_mode,
+            )
             self.to_destination, self.from_destination, did_fail, deadlocks = result
 
             n_deadlocks = len(deadlocks)
@@ -545,7 +559,12 @@ class BaseConfiguration:
     async def save_snapshot(self, highlight=None):
         """Saves a snapshot of the current robot grid."""
 
-        mjd = int(Time.now().mjd)
+        if self.assignment_data and self.assignment_data.observatory:
+            observatory = self.assignment_data.observatory.upper()
+        else:
+            observatory = None
+
+        mjd = get_sjd(observatory)
         dirpath = os.path.join(config["fps"]["configuration_snapshot_path"], str(mjd))
         if not os.path.exists(dirpath):
             os.makedirs(dirpath)
@@ -770,7 +789,7 @@ class BaseConfiguration:
             "instruments": "BOSS APOGEE",
             "epoch": adata.site.time.jd if adata.site.time else -999,
             "obstime": time.strftime("%a %b %d %H:%M:%S %Y"),
-            "MJD": int(get_sjd(adata.observatory.upper())),
+            "MJD": get_sjd(adata.observatory.upper()),
             "observatory": adata.observatory,
             "temperature": round(temp, 1),
             "raCen": -999.0,
@@ -1073,6 +1092,7 @@ class DitheredConfiguration(BaseConfiguration):
             *_,
         ) = await get_path_pair_in_executor(
             self.robot_grid,
+            path_generation_mode="greedy",
             ignore_did_fail=True,
             stop_if_deadlock=True,
             ignore_initial_collisions=True,
